@@ -40,7 +40,7 @@ email                : mte@users.sourceforge.net
 // ----------------------------------------------------------------------------
 // Third party Includes
 
-// ----------------------------------------------------------------------------
+// ------------------------------------------------------------Box21----------------
 // Project Includes
 #include "mymoneygncreader.h"
 #ifndef _GNCFILEANON
@@ -81,6 +81,7 @@ void MyMoneyGncReader::setOptions () {
     m_dropSuspectSchedules = dlg.scheduleOption();
     m_investmentOption = dlg.investmentOption();
     m_useFinanceQuote = dlg.quoteOption();
+    m_useTxNotes = dlg.txNotesOption();
     m_decoder = dlg.decodeOption();
     gncdebug = dlg.generalDebugOption();
     xmldebug = dlg.xmlDebugOption();
@@ -91,6 +92,9 @@ void MyMoneyGncReader::setOptions () {
     // investment option - 0, create investment a/c per stock a/c, 1 = single new investment account, 2 = prompt for each stock
     // option 2 doesn't really work too well at present
     m_investmentOption = 0;
+    m_useFinanceQuote = false;
+    m_useTxNotes = false;
+    m_decoder = 0;
     gncdebug = false; // general debug messages
     xmldebug = false; // xml trace
     bAnonymize = false; // anonymize input
@@ -158,7 +162,7 @@ bool GncObject::isDataElement (const QString &elName, const QXmlAttributes& elAt
 }
 
 // return the variable string, decoded if required
-const QString GncObject::var (int i) const {
+QString GncObject::var (int i) const {
   return (pMain->m_decoder == 0
       ? *(m_v.at(i))
       : pMain->m_decoder->toUnicode (*(m_v.at(i))));
@@ -530,7 +534,8 @@ void GncAccount::terminate() {
 //************* GncTransaction********************************************
 GncTransaction::GncTransaction (bool processingTemplates) {
   m_subElementListCount = END_Transaction_SELS;
-  static const QString subEls[] = {"trn:currency", "trn:date-posted", "trn:date-entered", "trn:split"};
+  static const QString subEls[] = {"trn:currency", "trn:date-posted", "trn:date-entered",
+    "trn:split", "slot"};
   m_subElementList = subEls;
   m_dataElementListCount = END_Transaction_DELS;
   static const QString dataEls[] = {"trn:id", "trn:num", "trn:description"};
@@ -565,6 +570,7 @@ GncObject *GncTransaction::startSubEl() {
       next = new GncSplit;
     }
     break;
+  case KVP: next = new GncKvp; break;
   default: throw new MYMONEYEXCEPTION ("GncTransaction rcvd invalid m_state");
   }
   return (next);
@@ -578,6 +584,7 @@ void GncTransaction::endSubEl(GncObject *subObj) {
   case POSTED: m_vpDatePosted = static_cast<GncDate *>(subObj); break;
   case ENTERED: m_vpDateEntered = static_cast<GncDate *>(subObj); break;
   case SPLIT: m_splitList.append (subObj); break;
+  case KVP: m_kvpList.append (subObj);
   }
   return ;
 }
@@ -812,7 +819,7 @@ void GncRecurrence::terminate() {
   return ;
 }
 
-const QString GncRecurrence::getFrequency() const {
+QString GncRecurrence::getFrequency() const {
   // This function converts a gnucash 2.2 recurrence specification into it's previous equivalent
   // This will all need re-writing when MTE finishes the schedule re-write
   if (periodType() == "once") return("once");
@@ -1348,23 +1355,30 @@ void MyMoneyGncReader::convertTransaction (const GncTransaction *gtx) {
   // the splits are in order in splitList. Link them to the tx. also, determine the
   // action type, and fill in some fields which gnc holds at transaction level
   // first off, is it a transfer (can only have 2 splits?)
-  if (m_splitList.count() != 2) m_potentialTransfer = false;
-  // at this point, if m_potentialTransfer is still true, it is actually one!
-  QString txMemo = "";
+  // also, a tx with just 2 splits is shown by GnuCash as non-split
+  bool nonSplitTx = true;
+  if (m_splitList.count() != 2) {
+    m_potentialTransfer = false;
+    nonSplitTx = false;
+  }
+  for (i = 0; i < gtx->kvpCount(); i++ ) {
+    const GncKvp *slot = gtx->getKvp(i);
+    if (slot->key() == "notes") tx.setMemo(slot->value());
+  }
   QValueList<MyMoneySplit>::iterator it = m_splitList.begin();
   while (!m_splitList.isEmpty()) {
     split = *it;
+    // at this point, if m_potentialTransfer is still true, it is actually one!
     if (m_potentialTransfer) split.setAction(MyMoneySplit::ActionTransfer);
-    //split.setNumber(gtx->no());
-    // Arbitrarily, save the first non-null split memo as the memo for the whole tx
-    // I think this is necessary because txs with just 2 splits (the majority)
-    // are not viewable as split transactions in kmm so the split memo is not seen
-    if ((txMemo.isEmpty()) && (!split.memo().isEmpty())) txMemo = split.memo();
+    if ((m_useTxNotes) // if use txnotes option is set
+         && (nonSplitTx) // and it's a (GnuCash) non-split transaction
+         && (!tx.memo().isEmpty())) // and tx notes are present
+      split.setMemo(tx.memo());  // use the tx notes as memo
     tx.addSplit(split);
     it = m_splitList.remove(it);
   }
-  // memo - set from split
-  tx.setMemo(txMemo);
+  // memo - set from split - not any more
+  //tx.setMemo(txMemo);
   m_storage->addTransaction(tx, true); // all done, add the transaction to storage
   signalProgress (++m_transactionCount, 0);
   return ;
@@ -1375,7 +1389,7 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
   MyMoneySplit split;
   MyMoneyAccount splitAccount;
   // find the kmm account id coresponding to the gnc id
-  QCString kmmAccountId;
+  QString kmmAccountId;
   map_accountIds::Iterator id = m_mapIds.find(gsp->acct().utf8());
   if (id != m_mapIds.end()) {
     kmmAccountId = id.data();
@@ -1496,7 +1510,7 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
   return ;
 }
 //********************************* convertTemplateTransaction **********************************************
-MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString schedName, const GncTransaction *gtx) {
+MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString& schedName, const GncTransaction *gtx) {
 
   Q_CHECK_PTR (gtx);
   MyMoneyTransaction tx;
@@ -1526,7 +1540,7 @@ MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString s
     convertTemplateSplit (schedName, static_cast<const GncTemplateSplit *>(gtx->getSplit (i)));
   }
   // determine the action type for the splits and link them to the template tx
-  /*QCString negativeActionType, positiveActionType;
+  /*QString negativeActionType, positiveActionType;
   if (!m_splitList.isEmpty()) { // if there are asset splits
     positiveActionType = MyMoneySplit::ActionDeposit;
     negativeActionType = MyMoneySplit::ActionWithdrawal;
@@ -1569,7 +1583,7 @@ MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString s
   return (tx);
 }
 //********************************* convertTemplateSplit ****************************************************
-void MyMoneyGncReader::convertTemplateSplit (const QString schedName, const GncTemplateSplit *gsp) {
+void MyMoneyGncReader::convertTemplateSplit (const QString& schedName, const GncTemplateSplit *gsp) {
   Q_CHECK_PTR (gsp);
   // convertTemplateSplit
   MyMoneySplit split;
@@ -1664,7 +1678,7 @@ void MyMoneyGncReader::convertTemplateSplit (const QString schedName, const GncT
     m_suspectSchedule = true;
   }
   // find the kmm account id coresponding to the gnc id
-  QCString kmmAccountId;
+  QString kmmAccountId;
   map_accountIds::Iterator id = m_mapIds.find(gncAccountId.utf8());
   if (id != m_mapIds.end()) {
     kmmAccountId = id.data();
@@ -1809,7 +1823,7 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   numOccurs = gsc->numOccurs().toInt();
   if (sc.lastPayment() == QDate()) {
     nextDate = lastDate = gsc->startDate();
-    while (nextDate < today) {
+    while ((nextDate < today)  && (numOccurs-- != 0)) {
       lastDate = nextDate;
       nextDate = incrDate (lastDate, vi[i].interval, vi[i].intervalCount);
     }
@@ -1821,6 +1835,7 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   // if an end date was specified, use it, otherwise if the input file had a number
   // of occurs remaining, work out the end date
   sc.setEndDate(gsc->endDate());
+  numOccurs = gsc->numOccurs().toInt();
   remOccurs = gsc->remOccurs().toInt();
   if ((sc.endDate() == QDate()) && (remOccurs > 0)) {
     endDate = sc.lastPayment();
@@ -1842,7 +1857,7 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   sc.setAutoEnter ((gsc->autoCreate() == "y") && (schedEnabled == "y"));
   //qDebug(QString("autoEnter set to %1").arg(sc.autoEnter()));
   // type
-  QCString actionType = tx.splits().first().action();
+  QString actionType = tx.splits().first().action();
   if (actionType == MyMoneySplit::ActionDeposit) {
     sc.setType((MyMoneySchedule::typeE)MyMoneySchedule::TYPE_DEPOSIT);
   } else if (actionType == MyMoneySplit::ActionTransfer) {
@@ -1922,7 +1937,7 @@ void MyMoneyGncReader::terminate () {
       if (gncdebug) qDebug("Account id %s is a child of root", (*acc).id().data());
     } else {
       // it is not under one of the main accounts, so find gnucash parent
-      QCString parentKey = (*acc).parentAccountId();
+      QString parentKey = (*acc).parentAccountId();
       if (gncdebug) qDebug ("acc %s, parent %s", (*acc).id().data(),
                               (*acc).parentAccountId().data());
       map_accountIds::Iterator id = m_mapIds.find(parentKey);
@@ -2017,7 +2032,7 @@ void MyMoneyGncReader::terminate () {
   PASS
 }
 //************************************ buildReportSection************************************
-const QString MyMoneyGncReader::buildReportSection (const QString source) {
+QString MyMoneyGncReader::buildReportSection (const QString& source) {
   TRY
   QString s = "";
   bool more = false;
@@ -2077,7 +2092,7 @@ const QString MyMoneyGncReader::buildReportSection (const QString source) {
   PASS
 }
 //************************ writeReportToFile*********************************
-bool MyMoneyGncReader::writeReportToFile (const QValueList<QString> sectionsToReport) {
+bool MyMoneyGncReader::writeReportToFile (const QValueList<QString>& sectionsToReport) {
   TRY
   unsigned int i;
   QFileDialog* fd = new QFileDialog (0, "Save report as", TRUE);
@@ -2106,7 +2121,7 @@ bool MyMoneyGncReader::writeReportToFile (const QValueList<QString> sectionsToRe
 *****************************************************************************/
 //************************ createPayee ***************************
 
-const QString MyMoneyGncReader::createPayee (const QString gncDescription) {
+QString MyMoneyGncReader::createPayee (const QString& gncDescription) {
   MyMoneyPayee payee;
   try {
     payee = m_storage->payeeByName (gncDescription);
@@ -2118,7 +2133,7 @@ const QString MyMoneyGncReader::createPayee (const QString gncDescription) {
   return (payee.id());
 }
 //************************************** createOrphanAccount *******************************
-const QCString MyMoneyGncReader::createOrphanAccount (const QString gncName) {
+QString MyMoneyGncReader::createOrphanAccount (const QString& gncName) {
   MyMoneyAccount acc;
 
   acc.setName ("orphan_" + gncName);
@@ -2187,7 +2202,7 @@ void MyMoneyGncReader::checkInvestmentOption (QString stockId) {
   // investment account. if it is, no further action is needed
   MyMoneyAccount stockAcc = m_storage->account (m_mapIds[stockId.utf8()]);
   MyMoneyAccount parent;
-  QCString parentKey = stockAcc.parentAccountId();
+  QString parentKey = stockAcc.parentAccountId();
   map_accountIds::Iterator id = m_mapIds.find (parentKey);
   if (id != m_mapIds.end()) {
     parent = m_storage->account (id.data());
@@ -2198,7 +2213,7 @@ void MyMoneyGncReader::checkInvestmentOption (QString stockId) {
   if (m_investmentOption == 0) {
     MyMoneyAccount invAcc (stockAcc);
     invAcc.setAccountType (MyMoneyAccount::Investment);
-    invAcc.setCurrencyId (QCString("")); // we don't know what currency it is!!
+    invAcc.setCurrencyId (QString("")); // we don't know what currency it is!!
     invAcc.setParentAccountId (parentKey); // intersperse it between old parent and child stock acct
     m_storage->addAccount (invAcc);
     m_mapIds [invAcc.id()] = invAcc.id(); // so stock account gets parented (again) to investment account later
@@ -2209,7 +2224,7 @@ void MyMoneyGncReader::checkInvestmentOption (QString stockId) {
     m_storage->addAccount(invAcc, stockAcc);
     // investment option 1 creates a single investment account for all stocks
   } else if (m_investmentOption == 1) {
-    static QCString singleInvAccId = "";
+    static QString singleInvAccId = "";
     MyMoneyAccount singleInvAcc;
     bool ok = false;
     if (singleInvAccId.isEmpty()) { // if the account has not yet been created
@@ -2221,7 +2236,7 @@ void MyMoneyGncReader::checkInvestmentOption (QString stockId) {
       }
       singleInvAcc.setName (invAccName);
       singleInvAcc.setAccountType (MyMoneyAccount::Investment);
-      singleInvAcc.setCurrencyId (QCString(""));
+      singleInvAcc.setCurrencyId (QString(""));
       singleInvAcc.setParentAccountId (m_storage->asset().id());
       m_storage->addAccount (singleInvAcc);
       m_mapIds [singleInvAcc.id()] = singleInvAcc.id(); // so stock account gets parented (again) to investment account later
@@ -2264,7 +2279,7 @@ void MyMoneyGncReader::checkInvestmentOption (QString stockId) {
         } else {                 // a new account name was entered
           invAcc.setAccountType (MyMoneyAccount::Investment);
           invAcc.setName (invAccName);
-          invAcc.setCurrencyId (QCString(""));
+          invAcc.setCurrencyId (QString(""));
           invAcc.setParentAccountId (m_storage->asset().id());
           m_storage->addAccount (invAcc);
           ok = true;
@@ -2356,21 +2371,21 @@ void MyMoneyGncReader::signalProgress(int current, int total, const QString& msg
 }
 // error and information reporting
 //***************************** Information and error messages *********************
-void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const char* arg1) {
+void MyMoneyGncReader::postMessage (const QString& source, const unsigned int code, const char* arg1) {
   postMessage (source, code, QStringList(arg1));
 }
-void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const char* arg1, const char* arg2) {
+void MyMoneyGncReader::postMessage (const QString& source, const unsigned int code, const char* arg1, const char* arg2) {
   QStringList argList(arg1);
   argList.append(arg2);
   postMessage(source, code, argList);
 }
-void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const char* arg1, const char* arg2, const char* arg3) {
+void MyMoneyGncReader::postMessage (const QString& source, const unsigned int code, const char* arg1, const char* arg2, const char* arg3) {
   QStringList argList(arg1);
   argList.append(arg2);
   argList.append(arg3);
   postMessage(source, code, argList);
 }
-void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const QStringList& argList) {
+void MyMoneyGncReader::postMessage (const QString& source, const unsigned int code, const QStringList& argList) {
   unsigned int i;
   GncMessageArgs *m = new GncMessageArgs;
 
