@@ -635,11 +635,11 @@ void InvestTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action /* action
 
     // fee amount
     value = dynamic_cast<kMyMoneyEdit*>(haveWidget("fee-amount"));
-    value->setValue(subtotal(m_feeSplits).abs());
+    value->setValue(subtotal(m_feeSplits));
 
     // interest amount
     value = dynamic_cast<kMyMoneyEdit*>(haveWidget("interest-amount"));
-    value->setValue(subtotal(m_interestSplits).abs());
+    value->setValue(-subtotal(m_interestSplits));
 
     // total
     slotUpdateTotalAmount();
@@ -694,9 +694,11 @@ QWidget* InvestTransactionEditor::firstWidget(void) const
   return 0; // let the creator use the first widget in the tab order
 }
 
-bool InvestTransactionEditor::isComplete(void) const
+bool InvestTransactionEditor::isComplete(QString& reason) const
 {
-  return d->m_activity->isComplete();
+  reason = QString();
+  // reason.clear();  // for Qt4
+  return d->m_activity->isComplete(reason);
 }
 
 MyMoneyMoney InvestTransactionEditor::subtotal(const QValueList<MyMoneySplit>& splits) const
@@ -754,7 +756,7 @@ void InvestTransactionEditor::totalAmount(MyMoneyMoney& amount) const
     amount = sharesEdit->value().abs() * priceEdit->value().abs();
 
   if(feesEdit->isVisible()) {
-    MyMoneyMoney fee = feesEdit->value().abs();
+    MyMoneyMoney fee = feesEdit->value();
     MyMoneyMoney factor(-1,1);
     switch(activityCombo->activity()) {
       case MyMoneySplit::BuyShares:
@@ -768,7 +770,7 @@ void InvestTransactionEditor::totalAmount(MyMoneyMoney& amount) const
   }
 
   if(interestEdit->isVisible()) {
-    MyMoneyMoney interest = interestEdit->value().abs();
+    MyMoneyMoney interest = interestEdit->value();
     MyMoneyMoney factor(1,1);
     switch(activityCombo->activity()) {
       case MyMoneySplit::BuyShares:
