@@ -28,7 +28,6 @@
 // KDE Includes
 
 #include <kpushbutton.h>
-#include <kiconloader.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -52,18 +51,8 @@ KNewEquityEntryDlg::KNewEquityEntryDlg(QWidget *parent, const char *name)
   connect(edtEquityName, SIGNAL(textChanged(const QString&)), this, SLOT(slotDataChanged()));
 
   // add icons to buttons
-  KIconLoader *il = KGlobal::iconLoader();
-  KGuiItem okButtenItem( i18n("&Ok" ),
-                    QIconSet(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall)),
-                    i18n("Accepts the value and stores them"),
-                    i18n("Use this to accept all values and close the dialog."));
-  btnOK->setGuiItem(okButtenItem);
-
-  KGuiItem cancelButtenItem( i18n( "&Cancel" ),
-                    QIconSet(il->loadIcon("button_cancel", KIcon::Small, KIcon::SizeSmall)),
-                    i18n("Cancel the operation"),
-                    i18n("Use this to dismiss all the changes made in this dialog."));
-  btnCancel->setGuiItem(cancelButtenItem);
+  btnOK->setGuiItem(KStdGuiItem::ok());
+  btnCancel->setGuiItem(KStdGuiItem::cancel());
 
   slotDataChanged();
 
