@@ -23,6 +23,7 @@
 #include <qeventloop.h>
 #include <qradiobutton.h>
 #include <qbuttongroup.h>
+#include <qtooltip.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -86,15 +87,30 @@ TransactionEditor::~TransactionEditor()
   emit finishEdit(m_transactions);
 }
 
-void TransactionEditor::slotUpdateAccount(const QCString& id)
+void TransactionEditor::slotUpdateAccount(const QString& id)
 {
   m_account = MyMoneyFile::instance()->account(id);
+  setupPrecision();
 }
 
 void TransactionEditor::slotUpdateAccount(void)
 {
   // reload m_account as it might have been changed
   m_account = MyMoneyFile::instance()->account(m_account.id());
+  setupPrecision();
+}
+
+void TransactionEditor::setupPrecision(void)
+{
+  const int prec = (m_account.id().isEmpty()) ? 2 : MyMoneyMoney::denomToPrec(m_account.fraction());
+  QStringList widgets = QStringList::split(",", "amount,deposit,payment");
+  QStringList::const_iterator it_w;
+  for(it_w = widgets.begin(); it_w != widgets.end(); ++it_w) {
+    QWidget * w;
+    if((w = haveWidget(*it_w)) != 0) {
+      dynamic_cast<kMyMoneyEdit*>(w)->setPrecision(prec);
+    }
+  }
 }
 
 void TransactionEditor::setup(QWidgetList& tabOrderWidgets, const MyMoneyAccount& account, KMyMoneyRegister::Action action)
@@ -213,7 +229,8 @@ void TransactionEditor::slotNumberChanged(const QString& txt)
 
 void TransactionEditor::slotUpdateButtonState(void)
 {
-  emit transactionDataSufficient(isComplete());
+  QString reason;
+  emit transactionDataSufficient(isComplete(reason));
 }
 
 QWidget* TransactionEditor::haveWidget(const QString& name) const
@@ -455,7 +472,7 @@ bool TransactionEditor::canAssignNumber(void) const
   return (number != 0) && (number->text().isEmpty());
 }
 
-void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QValueList<MyMoneySplit>& splits, QCString& categoryId, const char* splitEditSlot, bool /* allowObjectCreation */)
+void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QValueList<MyMoneySplit>& splits, QString& categoryId, const char* splitEditSlot, bool /* allowObjectCreation */)
 {
   disconnect(category, SIGNAL(focusIn()), this, splitEditSlot);
 #if 0
@@ -467,13 +484,13 @@ void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QV
 
   switch(splits.count()) {
     case 0:
-      categoryId = QCString();
+      categoryId = QString();
       if(!category->currentText().isEmpty()) {
         category->setCurrentText();
         // make sure, we don't see the selector
         category->completion()->hide();
       }
-      category->completion()->setSelected(QCString());
+      category->completion()->setSelected(QString());
       break;
 
     case 1:
@@ -483,7 +500,7 @@ void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QV
       break;
 
     default:
-      categoryId = QCString();
+      categoryId = QString();
       category->setSplitTransaction();
       connect(category, SIGNAL(focusIn()), this, splitEditSlot);
 #if 0
@@ -496,9 +513,9 @@ void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QV
   }
 }
 
-bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule, bool suppressBalanceWarnings)
+bool TransactionEditor::enterTransactions(QString& newId, bool askForSchedule, bool suppressBalanceWarnings)
 {
-  newId = QCString();
+  newId = QString();
   MyMoneyFile* file = MyMoneyFile::instance();
 
   // make sure to run through all stuff that is tied to 'focusout events'.
@@ -546,17 +563,17 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule,
 
     try {
       QValueList<MyMoneyTransaction>::iterator it_ts;
-      QMap<QCString, bool> minBalanceEarly;
-      QMap<QCString, bool> minBalanceAbsolute;
-      QMap<QCString, bool> maxCreditEarly;
-      QMap<QCString, bool> maxCreditAbsolute;
-      QMap<QCString, bool> accountIds;
+      QMap<QString, bool> minBalanceEarly;
+      QMap<QString, bool> minBalanceAbsolute;
+      QMap<QString, bool> maxCreditEarly;
+      QMap<QString, bool> maxCreditAbsolute;
+      QMap<QString, bool> accountIds;
 
       for(it_ts = list.begin(); it_ts != list.end(); ++it_ts) {
         // if we have a categorization, make sure we remove
         // the 'imported' flag automagically
         if((*it_ts).splitCount() > 1)
-          (*it_ts).deletePair("Imported");
+          (*it_ts).setImported(false);
 
         // create information about min and max balances
         QValueList<MyMoneySplit>::const_iterator it_s;
@@ -601,8 +618,9 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule,
             file->addTransaction(*it_ts);
             // pass the newly assigned id on to the caller
             newId = (*it_ts).id();
-            // refresh account object for transactional changes
+            // refresh account and transaction object because they might have changed
             m_account = file->account(m_account.id());
+            t = (*it_ts);
 
             // if a new transaction has a valid number, keep it with the account
             QString number = (*it_ts).splits()[0].number();
@@ -632,16 +650,24 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule,
 
       // update m_transactions to contain the newly created transaction so that
       // it is selected as the current one
+      // we need to do that before we commit the transaction to the engine
+      // as we need it during the update of the views that is caused by committing already.
       if(newTransactionCreated) {
         m_transactions.clear();
-        KMyMoneyRegister::SelectedTransaction s((*it_ts), (*it_ts).splits()[0]);
-        m_transactions.append(s);
+        MyMoneySplit s;
+        // a transaction w/o a single split should not exist and adding it
+        // should throw an exception in MyMoneyFile::addTransaction, but we
+        // remain on the save side of things to check for it
+        if(t.splitCount() > 0)
+          s = t.splits()[0];
+        KMyMoneyRegister::SelectedTransaction st(t, s);
+        m_transactions.append(st);
       }
 
       ft.commit();
 
       // now analyse the balances and spit out warnings to the user
-      QMap<QCString, bool>::const_iterator it_a;
+      QMap<QString, bool>::const_iterator it_a;
 
       if(!suppressBalanceWarnings) {
         for(it_a = accountIds.begin(); it_a != accountIds.end(); ++it_a) {
@@ -649,7 +675,7 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule,
           MyMoneyAccount acc = file->account(it_a.key());
           MyMoneyMoney balance = file->balance(acc.id());
           const MyMoneySecurity& sec = file->security(acc.currencyId());
-          QCString key;
+          QString key;
           key = "minBalanceEarly";
           if(!acc.value(key).isEmpty()) {
             if(minBalanceEarly[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
@@ -676,7 +702,7 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule,
           }
 
           if(!msg.isEmpty()) {
-            KMessageBox::information(m_regForm, msg);
+            emit balanceWarning(m_regForm, acc, msg);
           }
         }
       }
@@ -712,6 +738,24 @@ StdTransactionEditor::~StdTransactionEditor()
   }
 }
 
+bool StdTransactionEditor::eventFilter(QObject* o, QEvent* e)
+{
+  bool rc = TransactionEditor::eventFilter(o, e);
+
+#if 0
+  // this is sofar dead code here, as the focus out event for Comboboxes
+  // never comes along here. I don't know why (ipwizard - 2009-10-03)
+  if((e->type() == QEvent::FocusOut)
+  && (haveWidget("payee") == dynamic_cast<QWidget*>(o))) {
+    // loosing the focus on the payee widget?
+    qDebug("Loosing focus on payee");
+    KMyMoneyPayeeCombo* p = dynamic_cast<KMyMoneyPayeeCombo*>(haveWidget("payee"));
+    if(!p->selectedItem().isEmpty())
+      slotUpdatePayee(p->selectedItem());
+  }
+#endif
+  return rc;
+}
 
 void StdTransactionEditor::createEditWidgets(void)
 {
@@ -719,22 +763,22 @@ void StdTransactionEditor::createEditWidgets(void)
   account->setHint(i18n("Account"));
   m_editWidgets["account"] = account;
   connect(account, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(account, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateAccount(const QCString&)));
+  connect(account, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateAccount(const QString&)));
 
   KMyMoneyPayeeCombo* payee = new KMyMoneyPayeeCombo;
   payee->setHint(i18n("Payer/Receiver"));
   m_editWidgets["payee"] = payee;
   connect(payee, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(payee, SIGNAL(createItem(const QString&, QCString&)), this, SIGNAL(createPayee(const QString&, QCString&)));
+  connect(payee, SIGNAL(createItem(const QString&, QString&)), this, SIGNAL(createPayee(const QString&, QString&)));
   connect(payee, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
-  connect(payee, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdatePayee(const QCString&)));
+  connect(payee, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdatePayee(const QString&)));
 
   KMyMoneyCategory* category = new KMyMoneyCategory(0, 0, true);
   category->setHint(i18n("Category/Account"));
   m_editWidgets["category"] = category;
-  connect(category, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateCategory(const QCString&)));
+  connect(category, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateCategory(const QString&)));
   connect(category, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(category, SIGNAL(createItem(const QString&, QCString&)), this, SLOT(slotCreateCategory(const QString&, QCString&)));
+  connect(category, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateCategory(const QString&, QString&)));
   connect(category, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
   connect(category->splitButton(), SIGNAL(clicked()), this, SLOT(slotEditSplits()));
   category->splitButton()->setDisabled(true);
@@ -773,6 +817,7 @@ void StdTransactionEditor::createEditWidgets(void)
   }
 
   m_editWidgets["postdate"] = new kMyMoneyDateInput;
+  connect(m_editWidgets["postdate"], SIGNAL(dateChanged(const QDate&)), this, SLOT(slotUpdateButtonState()));
 
   kMyMoneyEdit* value = new kMyMoneyEdit;
   m_editWidgets["amount"] = value;
@@ -799,7 +844,7 @@ void StdTransactionEditor::createEditWidgets(void)
 
   KMyMoneyReconcileCombo* reconcile = new KMyMoneyReconcileCombo;
   m_editWidgets["status"] = reconcile;
-  connect(reconcile, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateButtonState()));
+  connect(reconcile, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateButtonState()));
 
   KMyMoneyRegister::QWidgetContainer::iterator it_w;
   for(it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
@@ -833,9 +878,11 @@ void StdTransactionEditor::createEditWidgets(void)
   label = new QLabel(i18n("Number"), 0);
   label->setAlignment(Qt::AlignVCenter | Qt::DontClip);
   m_editWidgets["number-label"] = label;
+
+  setupPrecision();
 }
 
-void StdTransactionEditor::setupCategoryWidget(QCString& categoryId)
+void StdTransactionEditor::setupCategoryWidget(QString& categoryId)
 {
   TransactionEditor::setupCategoryWidget(dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]), m_splits, categoryId, SLOT(slotEditSplits()));
 
@@ -843,7 +890,7 @@ void StdTransactionEditor::setupCategoryWidget(QCString& categoryId)
     m_shares = m_splits[0].shares();
 }
 
-bool StdTransactionEditor::isTransfer(const QCString& accId1, const QCString& accId2) const
+bool StdTransactionEditor::isTransfer(const QString& accId1, const QString& accId2) const
 {
   if(accId1.isEmpty() || accId2.isEmpty())
     return false;
@@ -932,14 +979,14 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
     }
     dynamic_cast<KMyMoneyReconcileCombo*>(m_editWidgets["status"])->setState(m_split.reconcileFlag());
 
-    QCString payeeId = m_split.payeeId();
+    QString payeeId = m_split.payeeId();
     if(!payeeId.isEmpty()) {
       payee->setSelectedItem(payeeId);
     }
 
     m_splits.clear();
     if(m_transaction.splitCount() < 2) {
-      category->completion()->setSelected(QCString());
+      category->completion()->setSelected(QString());
     } else {
       QValueList<MyMoneySplit>::const_iterator it_s;
       for(it_s = m_transaction.splits().begin(); it_s != m_transaction.splits().end(); ++it_s) {
@@ -948,7 +995,7 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
         m_splits.append(*it_s);
       }
     }
-    QCString categoryId;
+    QString categoryId;
     setupCategoryWidget(categoryId);
 
     if((w = haveWidget("cashflow")) != 0) {
@@ -1045,7 +1092,7 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
       w->setEnabled(false);
     }
 
-    category->completion()->setSelected(QCString());
+    category->completion()->setSelected(QString());
   }
 
   // allow kick off VAT processing again
@@ -1064,7 +1111,7 @@ void StdTransactionEditor::slotReloadEditWidgets(void)
 {
   // reload category widget
   KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
-  QCString categoryId = category->selectedItem();
+  QString categoryId = category->selectedItem();
 
   AccountSet aSet;
   aSet.addAccountGroup(MyMoneyAccount::Asset);
@@ -1086,7 +1133,7 @@ void StdTransactionEditor::slotReloadEditWidgets(void)
 
   // reload payee widget
   KMyMoneyPayeeCombo* payee = dynamic_cast<KMyMoneyPayeeCombo*>(m_editWidgets["payee"]);
-  QCString payeeId = payee->selectedItem();
+  QString payeeId = payee->selectedItem();
 
   payee->loadPayees(MyMoneyFile::instance()->payeeList());
 
@@ -1095,22 +1142,30 @@ void StdTransactionEditor::slotReloadEditWidgets(void)
   }
 }
 
-void StdTransactionEditor::slotUpdatePayee(const QCString& payeeId)
+void StdTransactionEditor::slotUpdatePayee(const QString& payeeId)
 {
   // we have a new payee assigned to this transaction.
+  // retrieve some information about the state of the category widget
+  KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
+  QStringList list;
+  category->selectedItems(list);
+
+  // If payee has associated default account (category), set that now if
+  // category is not filled
+  const MyMoneyPayee& payeeObj = MyMoneyFile::instance()->payee(payeeId);
+  if (payeeObj.defaultAccountEnabled() && list.isEmpty()) {
+    KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
+    category->slotItemSelected(payeeObj.defaultAccountId());
+    return;
+  }
+
   // in case there is no category assigned, no value entered and no
   // memo available, we search for the last transaction of this payee
   // in the account.
   if(m_transaction.id().isEmpty()
   && m_splits.count() == 0
-  && KMyMoneyGlobalSettings::autoFillTransaction()) {
-    // check if category is empty
-    KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
-    QCStringList list;
-    category->selectedItems(list);
-    if(!list.isEmpty())
-      return;
-
+  && KMyMoneyGlobalSettings::autoFillTransaction() != 0
+  && list.isEmpty()) {
     // check if memo is empty
     KTextEdit* memo = dynamic_cast<KTextEdit*>(m_editWidgets["memo"]);
     if(memo && !memo->text().isEmpty())
@@ -1161,7 +1216,12 @@ MyMoneyMoney StdTransactionEditor::shares(const MyMoneyTransaction& t) const
   return result;
 }
 
-void StdTransactionEditor::autoFill(const QCString& payeeId)
+struct uniqTransaction {
+  const MyMoneyTransaction* t;
+  int   cnt;
+};
+
+void StdTransactionEditor::autoFill(const QString& payeeId)
 {
   QValueList<QPair<MyMoneyTransaction, MyMoneySplit> >  list;
   MyMoneyTransactionFilter filter(m_account.id());
@@ -1172,23 +1232,24 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
     // what we have collected so far and add those splits from
     // the previous transaction.
     QValueList<QPair<MyMoneyTransaction, MyMoneySplit> >::const_iterator  it_t;
-    QMap<QString, const MyMoneyTransaction* > uniqList;
+    QMap<QString, struct uniqTransaction> uniqList;
 
     // collect the transactions and see if we have any duplicates
     for(it_t = list.begin(); it_t != list.end(); ++it_t) {
       QString key = (*it_t).first.accountSignature();
       int cnt = 0;
-      QMap<QString, const MyMoneyTransaction* >::iterator it_u;
+      QMap<QString, struct uniqTransaction>::iterator it_u;
       do {
         QString ukey = QString("%1-%2").arg(key).arg(cnt);
         it_u = uniqList.find(ukey);
         if(it_u == uniqList.end()) {
-          uniqList[ukey] = &((*it_t).first);
-        } else {
+          uniqList[ukey].t = &((*it_t).first);
+          uniqList[ukey].cnt = 1;
+        } else if (KMyMoneyGlobalSettings::autoFillTransaction() == 1) {
           // we already have a transaction with this signature. we must
           // now check, if we should really treat it as a duplicate according
           // to the value comparison delta.
-          MyMoneyMoney s1 = shares(*(*it_u));
+          MyMoneyMoney s1 = shares(*((*it_u).t));
           MyMoneyMoney s2 = shares((*it_t).first);
           if(s2.abs() > s1.abs()) {
             MyMoneyMoney t(s1);
@@ -1201,9 +1262,12 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
           else
             diff = ((s1 - s2) / s2).convert(10000);
           if(diff.isPositive() && diff <= MyMoneyMoney(KMyMoneyGlobalSettings::autoFillDifference(),100)) {
-            uniqList[ukey] = &((*it_t).first);
-            break;
+            uniqList[ukey].t = &((*it_t).first);
+            break;    // end while loop
           }
+        } else if (KMyMoneyGlobalSettings::autoFillTransaction() == 2) {
+          (*it_u).cnt++;
+          break;      // end while loop
         }
         ++cnt;
       } while(it_u != uniqList.end());
@@ -1211,28 +1275,48 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
     }
 
     MyMoneyTransaction t;
-    if(uniqList.count() == 1) {
-      t = list.last().first;
-    } else {
-      KSelectTransactionsDlg dlg(m_account, m_regForm);
-      dlg.setCaption(i18n("Select autofill transaction"));
+    if (KMyMoneyGlobalSettings::autoFillTransaction() != 2) {
+#if 0
+      // I removed this code to allow cancellation of an autofill if
+      // it does not match even if there is only a single matching
+      // transaction for the payee in question. In case, we want to revert
+      // to the old behavior, don't forget to uncomment the closing
+      // brace further down in the code as well. (ipwizard 2009-01-16)
+      if(uniqList.count() == 1) {
+        t = list.last().first;
+      } else {
+#endif
+        KSelectTransactionsDlg dlg(m_account, m_regForm);
+        dlg.setCaption(i18n("Select autofill transaction"));
 
-      QMap<QString, const MyMoneyTransaction*>::const_iterator it_u;
-      for(it_u = uniqList.begin(); it_u != uniqList.end(); ++it_u) {
-        dlg.addTransaction(*(*it_u));
+        QMap<QString, struct uniqTransaction>::const_iterator it_u;
+        for(it_u = uniqList.begin(); it_u != uniqList.end(); ++it_u) {
+          dlg.addTransaction(*(*it_u).t);
+        }
+
+        // setup sort order
+        dlg.m_register->setSortOrder("1,-9,-4");
+        // sort the transactions according to the sort setting
+        dlg.m_register->sortItems();
+
+        // and select the last item
+        if(dlg.m_register->lastItem())
+          dlg.m_register->selectItem(dlg.m_register->lastItem());
+
+        if(dlg.exec() == QDialog::Accepted) {
+          t = dlg.transaction();
+        }
+#if 0
       }
-
-      // setup sort order
-      dlg.m_register->setSortOrder("1,-9,-4");
-      // sort the transactions according to the sort setting
-      dlg.m_register->sortItems();
-
-      // and select the last item
-      if(dlg.m_register->lastItem())
-        dlg.m_register->selectItem(dlg.m_register->lastItem());
-
-      if(dlg.exec() == QDialog::Accepted) {
-        t = dlg.transaction();
+#endif
+    } else {
+      int maxCnt = 0;
+      QMap<QString, struct uniqTransaction>::const_iterator it_u;
+      for(it_u = uniqList.begin(); it_u != uniqList.end(); ++it_u) {
+        if((*it_u).cnt > maxCnt) {
+          t = *(*it_u).t;
+          maxCnt = (*it_u).cnt;
+        }
       }
     }
 
@@ -1251,7 +1335,7 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
         // we don't need this anymore
         if(s.action() != MyMoneySplit::ActionAmortization
         && s.action() != MyMoneySplit::ActionInterest)  {
-          s.setAction(QCString());
+          s.setAction(QString());
         }
 
         // FIXME update check number. The old comment contained
@@ -1356,7 +1440,7 @@ void StdTransactionEditor::slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirectio
   }
 }
 
-void StdTransactionEditor::slotUpdateCategory(const QCString& id)
+void StdTransactionEditor::slotUpdateCategory(const QString& id)
 {
   QLabel *categoryLabel = dynamic_cast<QLabel*>(haveWidget("category-label"));
   // qDebug("Update category to %s", id.data());
@@ -1386,10 +1470,13 @@ void StdTransactionEditor::slotUpdateCategory(const QCString& id)
           tabbar->tab(KMyMoneyRegister::ActionDeposit)->setEnabled(false);
           tabbar->tab(KMyMoneyRegister::ActionWithdrawal)->setEnabled(false);
         }
-        if(val.isNegative())
-          categoryLabel->setText(i18n("Transfer from"));
-        else
-          categoryLabel->setText(i18n("Transfer to"));
+        // only change the label if an amount is already filled in
+        if(!val.isZero()) {
+          if(val.isNegative())
+            categoryLabel->setText(i18n("Transfer from"));
+          else
+            categoryLabel->setText(i18n("Transfer to"));
+        }
       } else {
         if(tabbar)
           tabbar->tab(KMyMoneyRegister::ActionTransfer)->setEnabled(false);
@@ -1461,6 +1548,7 @@ void StdTransactionEditor::updateAmount(const MyMoneyMoney& val)
           cashflow->setDirection(KMyMoneyRegister::Payment);
         else
           cashflow->setDirection(KMyMoneyRegister::Deposit);
+        slotUpdateCashFlow(cashflow->direction());
       }
       dynamic_cast<kMyMoneyEdit*>(m_editWidgets["amount"])->setValue(val.abs());
     }
@@ -1561,11 +1649,10 @@ bool StdTransactionEditor::addVatSplit(MyMoneyTransaction& tr, const MyMoneyMone
       return false;
     }
 
-    MyMoneyMoney vatRate;
+    MyMoneyMoney vatRate(vatAcc.value("VatRate"));
     MyMoneyMoney gv, nv;    // gross value, net value
     int fract = m_account.fraction();
 
-    vatRate.fromString(vatAcc.value("VatRate"));
     if(!vatRate.isZero()) {
 
       tax.setAccountId(vatAcc.id());
@@ -1642,7 +1729,7 @@ MyMoneyMoney StdTransactionEditor::removeVatSplit(void)
   // block the signals to avoid popping up the split editor dialog
   // for nothing
   m_editWidgets["category"]->blockSignals(true);
-  QCString id;
+  QString id;
   setupCategoryWidget(id);
   m_editWidgets["category"]->blockSignals(false);
 
@@ -1650,9 +1737,24 @@ MyMoneyMoney StdTransactionEditor::removeVatSplit(void)
   return amount;
 }
 
-bool StdTransactionEditor::isComplete(void) const
+bool StdTransactionEditor::isComplete(QString& reason) const
 {
+  reason = QString();
+  // reason.clear();  // for Qt4
+
   QMap<QString, QWidget*>::const_iterator it_w;
+  kMyMoneyDateInput* postDate = dynamic_cast<kMyMoneyDateInput*>(m_editWidgets["postdate"]);
+  if(postDate) {
+    postDate->markAsBadDate();
+    QToolTip::remove(postDate);
+    if(postDate->date().isValid() && (postDate->date() < m_account.openingDate())) {
+      postDate->markAsBadDate(true, KMyMoneyGlobalSettings::listNegativeValueColor());
+      reason = i18n("Cannot enter transaction with postdate prior to account's opening date.");
+      QToolTip::add(postDate, reason);
+      return false;
+    }
+  }
+
   for(it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
     KMyMoneyPayeeCombo* payee = dynamic_cast<KMyMoneyPayeeCombo*>(*it_w);
     KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(*it_w);
@@ -1681,7 +1783,7 @@ bool StdTransactionEditor::isComplete(void) const
   return it_w != m_editWidgets.end();
 }
 
-void StdTransactionEditor::slotCreateCategory(const QString& name, QCString& id)
+void StdTransactionEditor::slotCreateCategory(const QString& name, QString& id)
 {
   MyMoneyAccount acc, parent;
   acc.setName(name);
@@ -1798,9 +1900,9 @@ int StdTransactionEditor::slotEditSplits(void)
   return rc;
 }
 
-void StdTransactionEditor::checkPayeeInSplit(MyMoneySplit& s, const QCString& payeeId)
+void StdTransactionEditor::checkPayeeInSplit(MyMoneySplit& s, const QString& payeeId)
 {
-  if(s.accountId().isEmpty() || payeeId.isEmpty())
+  if(s.accountId().isEmpty())
     return;
 
   MyMoneyAccount acc = MyMoneyFile::instance()->account(s.accountId());
@@ -1904,7 +2006,7 @@ bool StdTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyMone
   }
 
   KMyMoneyPayeeCombo* payee = dynamic_cast<KMyMoneyPayeeCombo*>(m_editWidgets["payee"]);
-  QCString payeeId;
+  QString payeeId;
   if(!isMultiSelection() || (isMultiSelection() && !payee->currentText().isEmpty())) {
     payeeId = payee->selectedItem();
     s0.setPayeeId(payeeId);
@@ -1941,7 +2043,7 @@ bool StdTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyMone
   QValueList<MyMoneySplit> splits = m_splits;
 
   MyMoneySplit s1;
-  if(torig.splitCount() < 2 && splits.count() == 0) {
+  if(splits.count() == 0) {
     s1.setMemo(s0.memo());
     splits.append(s1);
 
@@ -2041,7 +2143,7 @@ void StdTransactionEditor::setupFinalWidgets(void)
   addFinalWidget(haveWidget("status"));
 }
 
-void StdTransactionEditor::slotUpdateAccount(const QCString& id)
+void StdTransactionEditor::slotUpdateAccount(const QString& id)
 {
   TransactionEditor::slotUpdateAccount(id);
   KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
