@@ -44,12 +44,14 @@ class KPushButton;
 // ----------------------------------------------------------------------------
 // Project Includes
 
+#include <kmymoney/mymoneyaccount.h>
 #include <kmymoney/mymoneyscheduled.h>
 #include <kmymoney/mymoneyinstitution.h>
 #include <kmymoney/mymoneypayee.h>
 #include <kmymoney/mymoneybudget.h>
 #include <kmymoney/kmymoneyplugin.h>
 #include <kmymoney/register.h>
+#include <kmymoney/kmymoneyutils.h>
 
 class QSignalMapper;
 class KProgress;
@@ -61,7 +63,7 @@ class IMyMoneyStorage;
 class KFindTransactionDlg;
 class TransactionEditor;
 class KEndingBalanceDlg;
-class KMyMoneyPrivate;
+class KPluginInfo;
 
 namespace KMyMoneyPlugin { class ImporterPlugin; }
 
@@ -234,10 +236,10 @@ protected slots:
     * @param id reference to storage which will receive the id after successful creation
     *
     * @note Typically, this slot can be connected to the
-    *       StdTransactionEditor::createCategory(const QString&, QCString&) or
-    *       KMyMoneyCombo::createItem(const QString&, QCString&) signal.
+    *       StdTransactionEditor::createCategory(const QString&, QString&) or
+    *       KMyMoneyCombo::createItem(const QString&, QString&) signal.
     */
-  void slotCategoryNew(const QString& name, QCString& id);
+  void slotCategoryNew(const QString& name, QString& id);
 
   /**
     * Calls the print logic for the current view
@@ -282,7 +284,7 @@ protected slots:
 
   /**
     */
-  void slotPayeeNew(const QString& newnameBase, QCString& id);
+  void slotPayeeNew(const QString& newnameBase, QString& id);
   void slotPayeeNew(void);
 
   /**
@@ -416,7 +418,7 @@ protected slots:
     */
   void slotDataChanged(void);
 
-  void slotMoveToAccount(const QCString& id);
+  void slotMoveToAccount(const QString& id);
 
   void slotUpdateMoveToAccountMenu(void);
 
@@ -435,6 +437,7 @@ protected slots:
   void slotAccountMapOnline(void);
   void slotAccountUnmapOnline(void);
   void slotAccountUpdateOnline(void);
+  void slotAccountUpdateOnlineAll(void);
 
   void slotManageGpgKeys(void);
   void slotKeySelected(int idx);
@@ -496,9 +499,9 @@ public:
     * This method returns a list of all 'other' dcop registered kmymoney processes.
     * It's a subset of the return of DCOPclient()->registeredApplications().
     *
-    * @retval QCStringList of process ids
+    * @retval QStringList of process ids
     */
-  const QCStringList instanceList(void) const;
+  const QValueList<QCString> instanceList(void) const;
 
   /**
     * Dump a list of the names of all defined KActions to stdout.
@@ -533,6 +536,10 @@ public:
 
   KURL selectFile(const QString& title, const QString& path, const QString& mask, KFile::Mode mode);
 
+  const MyMoneyAccount& findAccount(const MyMoneyAccount& acc, const MyMoneyAccount& parent) const;
+
+  void createAccount(MyMoneyAccount& newAccount, MyMoneyAccount& parentAccount, MyMoneyAccount& brokerageAccount, MyMoneyMoney openingBal);
+
 k_dcop:
   // Note: Don't use e.g. filename(void) but use filename() because
   // otherwise the kidl compiler produces uncompilable results.
@@ -548,6 +555,8 @@ k_dcop:
     */
   bool okToWriteFile(const KURL& url);
 
+  // QValueList<MyMoneyAccount> accountList() const;
+
 protected:
   /** save general Options like all bar positions and status as well as the geometry and the recent file list to the configuration
    * file
@@ -602,8 +611,6 @@ protected:
 
   void createSchedule(MyMoneySchedule newSchedule, MyMoneyAccount& newAccount);
 
-  void createAccount(MyMoneyAccount& newAccount, MyMoneyAccount& parentAccount, MyMoneyAccount& brokerageAccount, MyMoneyMoney openingBal);
-
   /**
     * This method checks, if an account can be closed or not. An account
     * can be closed if:
@@ -627,7 +634,7 @@ protected:
     * @retval true object has been found
     * @retval false object is not in list
     */
-  bool payeeInList(const QValueList<MyMoneyPayee>& list, const QCString& id) const;
+  bool payeeInList(const QValueList<MyMoneyPayee>& list, const QString& id) const;
 
   /**
     * Mark the selected transactions as provided by @a flag. If
@@ -642,10 +649,19 @@ protected:
   void markTransaction(MyMoneySplit::reconcileFlagE flag);
 
   /**
-    * This slot allows to enter the next scheduled transaction of
-    * the given schedule
+    * This method allows to enter the next scheduled transaction of
+    * the given schedule @a s. In case @a extendedKeys is @a true,
+    * the given schedule can also be skipped or ignored.
+    * If @a autoEnter is @a true and the schedule does not contain
+    * an estimated value, the schedule is entered as is without further
+    * interaction with the user. In all other cases, the user will
+    * be presented a dialog and allowed to adjust the values for this
+    * instance of the schedule.
+    *
+    * The transaction will be created and entered into the ledger
+    * and the schedule updated.
     */
-  bool enterSchedule(MyMoneySchedule& s, bool autoEnter = false);
+  KMyMoneyUtils::EnterScheduleResultCodeE enterSchedule(MyMoneySchedule& s, bool autoEnter = false, bool extendedKeys = false);
 
   /**
     * Creates a new institution entry in the MyMoneyFile engine
@@ -940,11 +956,6 @@ public slots:
     */
   void slotToolsStartKCalc(void);
 
-  /**
-   * This slot shows the plugin dialog
-   */
-  void slotToolsPluginDlg(void);
-
   void slotResetSelections(void);
 
   void slotSelectAccount(const MyMoneyObject& account = MyMoneyAccount());
@@ -1008,6 +1019,16 @@ public slots:
     */
   void slotInstitutionNew(MyMoneyInstitution& institution);
 
+  /**
+    * Called whenever a plugin is plugged in
+    */
+  void slotPluginPlug(KPluginInfo*);
+
+  /**
+    * Called whenever a plugin is unplugged
+    */
+  void slotPluginUnplug(KPluginInfo*);
+
 private:
   // bool verifyImportedData(const MyMoneyAccount& account);
 
@@ -1042,7 +1063,7 @@ private:
     * into references to account @a toId. Returns @a true if at least
     * one split has been changed, @a false otherwise.
     */
-  bool exchangeAccountInTransaction(MyMoneyTransaction& _t, const QCString& fromId, const QCString& toId);
+  bool exchangeAccountInTransaction(MyMoneyTransaction& _t, const QString& fromId, const QString& toId);
 
 signals:
   /**
@@ -1116,10 +1137,10 @@ signals:
   void currencySelected(const MyMoneySecurity& currency);
 
   void payeeRename(void);
-  void payeeCreated(const QCString& id);
+  void payeeCreated(const QString& id);
 
   void currencyRename(void);
-  void currencyCreated(const QCString& id);
+  void currencyCreated(const QString& id);
 
   void startMatchTransaction(const MyMoneyTransaction& t);
   void cancelMatchTransaction(void);
@@ -1151,7 +1172,7 @@ public:
   KAction* action(const QString& actionName) const;
 
   /**
-    * This method is implemented for convience. It returns a dynamic_cast-ed
+    * This method is implemented for convenience. It returns a dynamic_cast-ed
     * pointer to an action found in actionCollection().
     * If the action with the name @p actionName is not found or the object
     * is not of type KToggleAction, a pointer to a static non-configured
@@ -1161,9 +1182,17 @@ public:
 
 
 private:
-  KMyMoneyPrivate*  d;
-  /** the configuration object of the application */
+  /// \internal d-pointer class.
+  class Private;
+  /*
+   * Actually, one should write "Private * const d" but that confuses the KIDL
+   * compiler in this context. It complains about the const keyword. So we leave
+   * it out here
+   */
+  /// \internal d-pointer instance.
+  Private* d;
 
+  /** the configuration object of the application */
   KConfig *config;
 
   QMap<QString,KMyMoneyPlugin::ImporterPlugin*> m_importerPlugins;
@@ -1254,7 +1283,7 @@ private:
   KEndingBalanceDlg*    m_endingBalanceDlg;
 
   // id's that need to be remembered
-  QCString              m_accountGoto, m_payeeGoto;
+  QString               m_accountGoto, m_payeeGoto;
 
   QStringList           m_additionalGpgKeys;
   QLabel*               m_additionalKeyLabel;
