@@ -14,11 +14,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <iostream>
+#include "mymoneyforecasttest.h"
 
+#include <iostream>
 #include <qvaluelist.h>
 
-#include "mymoneyforecasttest.h"
 #include "mymoneybudget.h"
 
 #include <kmymoney/mymoneyexception.h>
@@ -169,19 +169,18 @@ void MyMoneyForecastTest::testDoForecastInit() {
 void MyMoneyForecastTest::testDoForecast() {
   //set up environment
   MyMoneyForecast a;
-  
+
   MyMoneyAccount a_checking = file->account(acChecking);
   MyMoneyAccount a_credit = file->account(acCredit);
-  
+
   //test empty forecast
   a.doForecast(); //this is just to check nothing goes wrong if forecast is run agains an empty template
-  
+
   //setup some transactions
   TransactionHelper t1( QDate::currentDate().addDays(-1), MyMoneySplit::ActionWithdrawal, this->moT1, acChecking, acSolo);
   TransactionHelper t2( QDate::currentDate().addDays(-1), MyMoneySplit::ActionDeposit, -(this->moT2), acCredit, acParent);
   TransactionHelper t3( QDate::currentDate().addDays(-1), MyMoneySplit::ActionTransfer, this->moT1, acCredit, acChecking);
-  
-  
+
   a.setForecastMethod(1);
   a.setForecastDays(3);
   a.setAccountsCycle(1);
@@ -190,22 +189,21 @@ void MyMoneyForecastTest::testDoForecast() {
   a.setHistoryMethod(0); //moving average
   a.doForecast();
 
-  //checking didnt have balance variations, so the forecast should be equal to the current balance
+  //checking didn't have balance variations, so the forecast should be equal to the current balance
   MyMoneyMoney b_checking = file->balance(a_checking.id(), QDate::currentDate());
-  
+
   CPPUNIT_ASSERT(a.forecastBalance(a_checking, QDate::currentDate().addDays(1))==b_checking);
   CPPUNIT_ASSERT(a.forecastBalance(a_checking, QDate::currentDate().addDays(2))==b_checking);
   CPPUNIT_ASSERT(a.forecastBalance(a_checking, QDate::currentDate().addDays(3))==b_checking);
   CPPUNIT_ASSERT(a.forecastBalance(a_checking, QDate::currentDate())==b_checking);
-  
   //credit had a variation so the forecast should be different for each day
   MyMoneyMoney b_credit = file->balance(a_credit.id(), QDate::currentDate());
-  
+
   CPPUNIT_ASSERT(a.forecastBalance(a_credit, 0) == b_credit);
   CPPUNIT_ASSERT(a.forecastBalance(a_credit, QDate::currentDate().addDays(1)) == (b_credit+(moT2-moT1)));
   CPPUNIT_ASSERT(a.forecastBalance(a_credit, QDate::currentDate().addDays(2)) == (b_credit+((moT2-moT1)*2)));
   CPPUNIT_ASSERT(a.forecastBalance(a_credit, QDate::currentDate().addDays(3)) == b_credit+((moT2-moT1)*3));
-  
+
   a.setHistoryMethod(1); //weighted moving average
   a.doForecast();
 
@@ -218,7 +216,7 @@ void MyMoneyForecastTest::testDoForecast() {
   TransactionHelper t4( QDate::currentDate().addDays(-2), MyMoneySplit::ActionDeposit, -moT2, acCredit, acParent );
   TransactionHelper t5( QDate::currentDate().addDays(-10), MyMoneySplit::ActionDeposit, -moT2, acCredit, acParent );
   TransactionHelper t6( QDate::currentDate().addDays(-3), MyMoneySplit::ActionDeposit, -moT2, acCredit, acParent );
-  
+
   a.setForecastMethod(1);
   a.setForecastDays(3);
   a.setAccountsCycle(1);
@@ -241,7 +239,8 @@ void MyMoneyForecastTest::testDoForecast() {
   a.setForecastDays(3);
   a.setAccountsCycle(1);
   a.setForecastCycles(3);
-  a.setBeginForecastDay(0);  a.setHistoryMethod(1); //weighted moving average
+  a.setBeginForecastDay(0);
+  a.setHistoryMethod(1);
   a.doForecast();
 
   CPPUNIT_ASSERT(a.forecastBalance(a_credit, 0) == b_credit);
@@ -316,6 +315,7 @@ void MyMoneyForecastTest::testGetForecastBalance()
   a.setForecastDays(3);
   a.setAccountsCycle(1);
   a.setForecastCycles(1);
+  a.setHistoryMethod(0);
   a.doForecast();
   
   MyMoneyAccount a_checking = file->account(acChecking);
@@ -393,7 +393,7 @@ void MyMoneyForecastTest::testScheduleForecast()
   MyMoneyFileTransaction ft;
   MyMoneySchedule sch( "A Name",
                        MyMoneySchedule::TYPE_BILL,
-                       MyMoneySchedule::OCCUR_WEEKLY,
+                       MyMoneySchedule::OCCUR_WEEKLY, 1,
                        MyMoneySchedule::STYPE_DIRECTDEBIT,
                        QDate::currentDate().addDays(1),
                                           QDate(),
@@ -435,7 +435,7 @@ void MyMoneyForecastTest::testScheduleForecast()
   MyMoneyFileTransaction ft3;
   MyMoneySchedule sch3( "A Name1",
                        MyMoneySchedule::TYPE_BILL,
-                       MyMoneySchedule::OCCUR_WEEKLY,
+                       MyMoneySchedule::OCCUR_WEEKLY, 1,
                        MyMoneySchedule::STYPE_DIRECTDEBIT,
                        QDate::currentDate().addDays(5),
                                           QDate(),
@@ -482,7 +482,7 @@ void MyMoneyForecastTest::testScheduleForecast()
   MyMoneyFileTransaction ft2;
   MyMoneySchedule sch2( "A Name2",
                        MyMoneySchedule::TYPE_BILL,
-                       MyMoneySchedule::OCCUR_WEEKLY,
+                       MyMoneySchedule::OCCUR_WEEKLY, 1,
                        MyMoneySchedule::STYPE_DIRECTDEBIT,
                        QDate::currentDate().addDays(2),
                                           QDate(),
@@ -638,6 +638,7 @@ void MyMoneyForecastTest::testSkipOpeningDate()
   a.setForecastDays(3);
   a.setAccountsCycle(2);
   a.setForecastCycles(1);
+  a.setHistoryMethod(0);
   a.doForecast();
   
   MyMoneyAccount a_cash = file->account(acCash);
@@ -663,6 +664,7 @@ void MyMoneyForecastTest::testAccountMinimumBalanceDateList() {
   a.setForecastDays(6);
   a.setAccountsCycle(2);
   a.setForecastCycles(3);
+  a.setHistoryMethod(0);
   a.setBeginForecastDay(QDate::currentDate().addDays(1).day());
   a.doForecast();
   
@@ -697,6 +699,7 @@ void MyMoneyForecastTest::testAccountMaximumBalanceDateList() {
   a.setForecastDays(6);
   a.setAccountsCycle(2);
   a.setForecastCycles(3);
+  a.setHistoryMethod(0);
   a.setBeginForecastDay(QDate::currentDate().addDays(1).day());
   a.doForecast();
   
@@ -905,7 +908,7 @@ void MyMoneyForecastTest::testCreateBudget()
   MyMoneyFileTransaction ft;
   MyMoneySchedule sch( "A Name",
                        MyMoneySchedule::TYPE_BILL,
-                       MyMoneySchedule::OCCUR_MONTHLY,
+                       MyMoneySchedule::OCCUR_MONTHLY, 1,
                        MyMoneySchedule::STYPE_DIRECTDEBIT,
                        QDate::currentDate(),
                                           QDate(),
@@ -950,8 +953,25 @@ void MyMoneyForecastTest::testCreateBudget()
   c.setForecastCycles(1);
   c.createBudget(budget, QDate::currentDate().addYears(-2), QDate::currentDate().addYears(-1), QDate::currentDate().addMonths(-2), QDate::currentDate().addMonths(6), true);
 
-  MyMoneyMoney c_parent = c.forecastBalance(a_parent, QDate(QDate::currentDate().year(), QDate::currentDate().month()+1, 1) );
+  MyMoneyMoney c_parent = c.forecastBalance(a_parent, QDate(QDate::currentDate().addMonths(1).year(), QDate::currentDate().addMonths(1).month(), 1) );
 
   //test valid results
-  CPPUNIT_ASSERT(c.forecastBalance(a_parent, QDate(QDate::currentDate().year(), QDate::currentDate().month()+1, 1) ) == (moT2));
+  CPPUNIT_ASSERT(c.forecastBalance(a_parent, QDate(QDate::currentDate().addMonths(1).year(), QDate::currentDate().addMonths(1).month(), 1) ) == (moT2));
+}
+
+void MyMoneyForecastTest::testLinearRegression() {
+  //set up environment
+  MyMoneyForecast a;
+
+  MyMoneyAccount a_checking = file->account(acChecking);
+  MyMoneyAccount a_credit = file->account(acCredit);
+
+  //setup some transactions
+  TransactionHelper t1( QDate::currentDate().addDays(-1), MyMoneySplit::ActionWithdrawal, this->moT1, acChecking, acSolo);
+  TransactionHelper t2( QDate::currentDate().addDays(-1), MyMoneySplit::ActionDeposit, -(this->moT2), acCredit, acParent);
+  TransactionHelper t3( QDate::currentDate().addDays(-1), MyMoneySplit::ActionTransfer, this->moT1, acCredit, acChecking);
+
+//TODO Add tests specific for linear regression
+  
+  
 }
