@@ -166,6 +166,11 @@ void MyMoneyMoneyTest::testStringConstructor()
   CPPUNIT_ASSERT(m1->m_num == LLCONST(-1234567));
   CPPUNIT_ASSERT(m1->m_denom == 1000);
   delete m1;
+
+  m1 = new MyMoneyMoney("1 5/8");
+  CPPUNIT_ASSERT(m1->m_num == LLCONST(13));
+  CPPUNIT_ASSERT(m1->m_denom == 8);
+  delete m1;
 }
 
 void MyMoneyMoneyTest::testConvert()
@@ -383,6 +388,9 @@ void MyMoneyMoneyTest::testFormatMoney()
 
   m1 = MyMoneyMoney(13333,5000);
   CPPUNIT_ASSERT(m1.formatMoney("", 10) == QString("2.6666000000"));
+
+  m1 = MyMoneyMoney(-1404,100);
+  CPPUNIT_ASSERT(m1.formatMoney("",-1) == QString("-14.04"));
 }
 
 void MyMoneyMoneyTest::testRelation()
@@ -459,24 +467,6 @@ void MyMoneyMoneyTest::testToString()
   CPPUNIT_ASSERT(m3.toString() == QString("0/1"));
 }
 
-void MyMoneyMoneyTest::testFromString()
-{
-  MyMoneyMoney m;
-
-  m.fromString("-100/100");
-  CPPUNIT_ASSERT(m.m_num == LLCONST(-100));
-  CPPUNIT_ASSERT(m.m_denom == LLCONST(100));
-  m.fromString("1234/100");
-  CPPUNIT_ASSERT(m.m_num == LLCONST(1234));
-  CPPUNIT_ASSERT(m.m_denom == LLCONST(100));
-  m.fromString("1234/10");
-  CPPUNIT_ASSERT(m.m_num == LLCONST(1234));
-  CPPUNIT_ASSERT(m.m_denom == LLCONST(10));
-  m.fromString("1234/2");
-  CPPUNIT_ASSERT(m.m_num == LLCONST(1234));
-  CPPUNIT_ASSERT(m.m_denom == LLCONST(2));
-}
-
 void MyMoneyMoneyTest::testNegativeSignPos(void)
 {
   MyMoneyMoney m("-123456/100");
