@@ -187,32 +187,57 @@ void MyMoneyTransactionTest::testModifySplits() {
 }
 
 void MyMoneyTransactionTest::testDeleteSplits() {
-	testAddSplits();
-	MyMoneySplit split;
+        testAddSplits();
+        MyMoneySplit split;
 
-	split.setId("S00000000");
-	// this one should fail, because the ID is invalid
-	try {
-		m->modifySplit(split);
-		CPPUNIT_FAIL("Exception expected");
-	} catch(MyMoneyException *e) {
-		delete e;
-	}
+        // add a third split
+        split.setAccountId("A000003");
+        split.setValue(MyMoneyMoney(300));
+        try {
+          m->addSplit(split);
+        } catch(MyMoneyException *e) {
+                CPPUNIT_FAIL("Unexpected exception!");
+                delete e;
+        }
 
-	// set id to correct value, and check that it worked
-	split.setId("S0001");
-	try {
-		m->removeSplit(split);
+        split.setId("S00000000");
+        // this one should fail, because the ID is invalid
+        try {
+                m->modifySplit(split);
+                CPPUNIT_FAIL("Exception expected");
+        } catch(MyMoneyException *e) {
+                delete e;
+        }
+
+        // set id to correct value, and check that it worked
+        split.setId("S0002");
+        try {
+                m->removeSplit(split);
+                CPPUNIT_ASSERT(m->splitCount() == 2);
+                CPPUNIT_ASSERT(m->splits()[0].accountId() == "A000001");
+                CPPUNIT_ASSERT(m->accountReferenced("A000002") == false);
+                CPPUNIT_ASSERT(m->accountReferenced("A000001") == true);
+                CPPUNIT_ASSERT(m->accountReferenced("A000003") == true);
+                CPPUNIT_ASSERT(m->splits()[0].id() == "S0001");
+
+        } catch(MyMoneyException *e) {
+                CPPUNIT_FAIL("Unexpected exception!");
+                delete e;
+        }
+
+        // set id to the other correct value, and check that it worked
+        split.setId("S0003");
+        try {
+                m->removeSplit(split);
                 CPPUNIT_ASSERT(m->splitCount() == 1);
-                CPPUNIT_ASSERT(m->splits()[0].accountId() == "A000002");
-                CPPUNIT_ASSERT(m->accountReferenced("A000001") == false);
-                CPPUNIT_ASSERT(m->accountReferenced("A000002") == true);
-                CPPUNIT_ASSERT(m->splits()[0].id() == "S0002");
+                CPPUNIT_ASSERT(m->accountReferenced("A000001") == true);
+                CPPUNIT_ASSERT(m->accountReferenced("A000003") == false);
+                CPPUNIT_ASSERT(m->splits()[0].id() == "S0001");
 
-	} catch(MyMoneyException *e) {
-		CPPUNIT_FAIL("Unexpected exception!");
-		delete e;
-	}
+        } catch(MyMoneyException *e) {
+                CPPUNIT_FAIL("Unexpected exception!");
+                delete e;
+        }
 }
 
 void MyMoneyTransactionTest::testDeleteAllSplits() {
@@ -465,6 +490,63 @@ void MyMoneyTransactionTest::testReadXML() {
 	}
 }
 
+void MyMoneyTransactionTest::testReadXMLEx()
+{
+        MyMoneyTransaction t;
+
+        QString ref_ok = QString(
+  "<!DOCTYPE TEST>\n"
+  "<TRANSACTION-CONTAINER>\n"
+  "<TRANSACTION postdate=\"2010-03-05\" memo=\"\" id=\"T000000000000004189\" commodity=\"EUR\" entrydate=\"2010-03-08\" >\n"
+  " <SPLITS>\n"
+  "  <SPLIT payee=\"P000010\" reconciledate=\"\" shares=\"-125000/100\" action=\"Transfer\" bankid=\"A000076-2010-03-05-b6850c0-1\" number=\"\" reconcileflag=\"1\" memo=\"UMBUCHUNG\" value=\"-125000/100\" id=\"S0001\" account=\"A000076\" >\n"
+  "   <KEYVALUEPAIRS>\n"
+  "    <PAIR key=\"kmm-match-split\" value=\"S0002\" />\n"
+  "    <PAIR key=\"kmm-matched-tx\" value=\"&amp;lt;!DOCTYPE MATCH>\n"
+  "    &amp;lt;CONTAINER>\n"
+  "     &amp;lt;TRANSACTION postdate=&quot;2010-03-05&quot; memo=&quot;UMBUCHUNG&quot; id=&quot;&quot; commodity=&quot;EUR&quot; entrydate=&quot;2010-03-08&quot; >\n"
+  "      &amp;lt;SPLITS>\n"
+  "       &amp;lt;SPLIT payee=&quot;P000010&quot; reconciledate=&quot;&quot; shares=&quot;125000/100&quot; action=&quot;Transfer&quot; bankid=&quot;&quot; number=&quot;&quot; reconcileflag=&quot;0&quot; memo=&quot;UMBUCHUNG&quot; value=&quot;125000/100&quot; id=&quot;S0001&quot; account=&quot;A000087&quot; />\n"
+  "       &amp;lt;SPLIT payee=&quot;P000010&quot; reconciledate=&quot;&quot; shares=&quot;-125000/100&quot; action=&quot;&quot; bankid=&quot;A000076-2010-03-05-b6850c0-1&quot; number=&quot;&quot; reconcileflag=&quot;0&quot; memo=&quot;UMBUCHUNG&quot; value=&quot;-125000/100&quot; id=&quot;S0002&quot; account=&quot;A000076&quot; />\n"
+  "      &amp;lt;/SPLITS>\n"
+  "      &amp;lt;KEYVALUEPAIRS>\n"
+  "       &amp;lt;PAIR key=&quot;Imported&quot; value=&quot;true&quot; />\n"
+  "      &amp;lt;/KEYVALUEPAIRS>\n"
+  "     &amp;lt;/TRANSACTION>\n"
+  "    &amp;lt;/CONTAINER>\n"
+  "\" />\n"
+  "    <PAIR key=\"kmm-orig-memo\" value=\"\" />\n"
+  "   </KEYVALUEPAIRS>\n"
+  "  </SPLIT>\n"
+  "  <SPLIT payee=\"P000010\" reconciledate=\"\" shares=\"125000/100\" action=\"Transfer\" bankid=\"\" number=\"\" reconcileflag=\"0\" memo=\"\" value=\"125000/100\" id=\"S0002\" account=\"A000087\" />\n"
+  " </SPLITS>\n"
+  "</TRANSACTION>\n"
+  "</TRANSACTION-CONTAINER>\n"
+  );
+	QDomDocument doc;
+	QDomElement node;
+	doc.setContent(ref_ok);
+	node = doc.documentElement().firstChild().toElement();
+
+	try {
+		t = MyMoneyTransaction(node);
+		CPPUNIT_ASSERT(t.pairs().count() == 0);
+		CPPUNIT_ASSERT(t.splits().count() == 2);
+		CPPUNIT_ASSERT(t.splits()[0].pairs().count() == 3);
+		CPPUNIT_ASSERT(t.splits()[1].pairs().count() == 0);
+		CPPUNIT_ASSERT(t.splits()[0].isMatched());
+
+		MyMoneyTransaction ti = t.splits()[0].matchedTransaction();
+		CPPUNIT_ASSERT(ti.pairs().count() == 1);
+		CPPUNIT_ASSERT(ti.isImported());
+		CPPUNIT_ASSERT(ti.splits().count() == 2);
+	} catch(MyMoneyException *e) {
+		delete e;
+		CPPUNIT_FAIL("Unexpected exception");
+	}
+
+}
+
 void MyMoneyTransactionTest::testHasReferenceTo()
 {
 	MyMoneyTransaction t;
