@@ -18,7 +18,6 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#ifdef USE_OFX_DIRECTCONNECT
 
 // ----------------------------------------------------------------------------
 // System Includes
@@ -47,6 +46,31 @@
 #include <kmymoney/mymoneykeyvaluecontainer.h>
 #include "mymoneyofxconnector.h"
 
+OfxHeaderVersion::OfxHeaderVersion(KComboBox* combo, const QString& headerVersion) :
+  m_combo(combo)
+{
+  combo->clear();
+  combo->insertItem("102");
+  combo->insertItem("103");
+
+  if(!headerVersion.isEmpty()) {
+    combo->setCurrentItem(headerVersion);
+  } else {
+    combo->setCurrentItem("102");
+  }
+
+#if ! LIBOFX_IS_VERSION(0,9,0)
+  // This feature does not work with libOFX < 0.9 so
+  // we just make disable the button in this case
+  combo->setDisabled(true);
+#endif
+}
+
+QString OfxHeaderVersion::headerVersion(void) const
+{
+  return m_combo->currentText();
+}
+
 OfxAppVersion::OfxAppVersion(KComboBox* combo, const QString& appId) :
   m_combo(combo)
 {
@@ -54,6 +78,8 @@ OfxAppVersion::OfxAppVersion(KComboBox* combo, const QString& appId) :
 // http://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-microsoft-money/
 
   // Quicken
+  m_appMap[i18n("Quicken Windows 2003")] = "QWIN:1200";
+  m_appMap[i18n("Quicken Windows 2004")] = "QWIN:1300";
   m_appMap[i18n("Quicken Windows 2005")] = "QWIN:1400";
   m_appMap[i18n("Quicken Windows 2006")] = "QWIN:1500";
   m_appMap[i18n("Quicken Windows 2007")] = "QWIN:1600";
@@ -116,6 +142,22 @@ QString MyMoneyOfxConnector::password(void) const { return m_fiSettings.value("p
 QString MyMoneyOfxConnector::accountnum(void) const { return m_fiSettings.value("accountid"); }
 QString MyMoneyOfxConnector::url(void) const { return m_fiSettings.value("url"); }
 
+QDate MyMoneyOfxConnector::statementStartDate(void) const {
+  if ((m_fiSettings.value("kmmofx-todayMinus").toInt() != 0) && !m_fiSettings.value("kmmofx-numRequestDays").isEmpty())
+  {
+    return QDate::currentDate().addDays(-m_fiSettings.value("kmmofx-numRequestDays").toInt());
+  }
+  else if ((m_fiSettings.value("kmmofx-lastUpdate").toInt() != 0) && !m_account.value("lastImportedTransactionDate").isEmpty())
+  {
+    return QDate::fromString(m_account.value("lastImportedTransactionDate"), Qt::ISODate);
+  }
+  else if ((m_fiSettings.value("kmmofx-pickDate").toInt() != 0) && !m_fiSettings.value("kmmofx-specificDate").isEmpty())
+  {
+    return QDate::fromString(m_fiSettings.value("kmmofx-specificDate"));
+  }
+  return QDate::currentDate().addMonths(-2);
+}
+
 #if LIBOFX_IS_VERSION(0,9,0)
 OfxAccountData::AccountType MyMoneyOfxConnector::accounttype(void) const
 {
@@ -215,28 +257,41 @@ AccountType MyMoneyOfxConnector::accounttype(void) const
 }
 #endif
 
-#if LIBOFX_IS_VERSION(0,9,0)
-const QByteArray MyMoneyOfxConnector::statementRequest(const QDate& _dtstart) const
+void MyMoneyOfxConnector::initRequest(OfxFiLogin* fi) const
 {
-  OfxFiLogin fi;
-  memset(&fi,0,sizeof(OfxFiLogin));
-  strncpy(fi.fid,fiid().latin1(),OFX_FID_LENGTH-1);
-  strncpy(fi.org,fiorg().latin1(),OFX_ORG_LENGTH-1);
-  strncpy(fi.userid,username().latin1(),OFX_USERID_LENGTH-1);
-  strncpy(fi.userpass,password().latin1(),OFX_USERPASS_LENGTH-1);
+  memset(fi,0,sizeof(OfxFiLogin));
+  strncpy(fi->fid, fiid().latin1(), OFX_FID_LENGTH-1);
+  strncpy(fi->org, fiorg().latin1(), OFX_ORG_LENGTH-1);
+  strncpy(fi->userid, username().latin1(), OFX_USERID_LENGTH-1);
+  strncpy(fi->userpass, password().latin1(), OFX_USERPASS_LENGTH-1);
+
+#if LIBOFX_IS_VERSION(0,9,0)
   // If we don't know better, we pretend to be Quicken 2008
   // http://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-intuit-products/
   // http://ofxblog.wordpress.com/2007/06/06/ofx-appid-and-appver-for-microsoft-money/
   QString appId = m_account.onlineBankingSettings().value("appId");
   QRegExp exp("(.*):(.*)");
   if(exp.search(appId) != -1) {
-    strncpy(fi.appid, exp.cap(1).latin1(), OFX_APPID_LENGTH-1);
-    strncpy(fi.appver, exp.cap(2).latin1(), OFX_APPVER_LENGTH-1);
+    strncpy(fi->appid, exp.cap(1).latin1(), OFX_APPID_LENGTH-1);
+    strncpy(fi->appver, exp.cap(2).latin1(), OFX_APPVER_LENGTH-1);
   } else {
-    strncpy(fi.appid, "QWIN", OFX_APPID_LENGTH-1);
-    strncpy(fi.appver, "1700", OFX_APPVER_LENGTH-1);
+    strncpy(fi->appid, "QWIN", OFX_APPID_LENGTH-1);
+    strncpy(fi->appver, "1700", OFX_APPVER_LENGTH-1);
   }
 
+  QString headerVersion = m_account.onlineBankingSettings().value("kmmofx-headerVersion");
+  if(!headerVersion.isEmpty()) {
+    strncpy(fi->header_version, headerVersion.latin1(), OFX_HEADERVERSION_LENGTH-1);
+  }
+#endif
+}
+
+const QByteArray MyMoneyOfxConnector::statementRequest(void) const
+{
+  OfxFiLogin fi;
+  initRequest(&fi);
+
+#if LIBOFX_IS_VERSION(0,9,0)
   OfxAccountData account;
   memset(&account,0,sizeof(OfxAccountData));
 
@@ -246,27 +301,7 @@ const QByteArray MyMoneyOfxConnector::statementRequest(const QDate& _dtstart) co
   }
   strncpy(account.account_number,accountnum().latin1(),OFX_ACCTID_LENGTH-1);
   account.account_type = accounttype();
-
-  char* szrequest = libofx_request_statement( &fi, &account, QDateTime(_dtstart).toTime_t() );
-  QString request = szrequest;
-  // remove the trailing zero
-  QByteArray result = request.utf8();
-  result.truncate(result.size()-1);
-  free(szrequest);
-
-  QString msg(result);
-  return result;
-}
 #else
-const QByteArray MyMoneyOfxConnector::statementRequest(const QDate& _dtstart) const
-{
-  OfxFiLogin fi;
-  memset(&fi,0,sizeof(OfxFiLogin));
-  strncpy(fi.fid,fiid().latin1(),OFX_FID_LENGTH-1);
-  strncpy(fi.org,fiorg().latin1(),OFX_ORG_LENGTH-1);
-  strncpy(fi.userid,username().latin1(),OFX_USERID_LENGTH-1);
-  strncpy(fi.userpass,password().latin1(),OFX_USERPASS_LENGTH-1);
-
   OfxAccountInfo account;
   memset(&account,0,sizeof(OfxAccountInfo));
 
@@ -276,8 +311,9 @@ const QByteArray MyMoneyOfxConnector::statementRequest(const QDate& _dtstart) co
   }
   strncpy(account.accountid,accountnum().latin1(),OFX_ACCOUNT_ID_LENGTH-1);
   account.type = accounttype();
+#endif
 
-  char* szrequest = libofx_request_statement( &fi, &account, QDateTime(_dtstart).toTime_t() );
+  char* szrequest = libofx_request_statement( &fi, &account, QDateTime(statementStartDate()).toTime_t() );
   QString request = szrequest;
   // remove the trailing zero
   QByteArray result = request.utf8();
@@ -287,16 +323,14 @@ const QByteArray MyMoneyOfxConnector::statementRequest(const QDate& _dtstart) co
   QString msg(result);
   return result;
 }
-#endif
 
+#if 0
+// this code is not used anymore. The logic is now
+// contained in KOnlineBankingSetupWizard::finishLoginPage(void)
 const QByteArray MyMoneyOfxConnector::accountInfoRequest(void) const
 {
   OfxFiLogin fi;
-  memset(&fi,0,sizeof(OfxFiLogin));
-  strncpy(fi.fid,fiid().latin1(),OFX_FID_LENGTH-1);
-  strncpy(fi.org,fiorg().latin1(),OFX_ORG_LENGTH-1);
-  strncpy(fi.userid,username().latin1(),OFX_USERID_LENGTH-1);
-  strncpy(fi.userpass,password().latin1(),OFX_USERPASS_LENGTH-1);
+  initRequest(&fi);
 
   char* szrequest = libofx_request_accountinfo( &fi );
   QString request = szrequest;
@@ -307,6 +341,8 @@ const QByteArray MyMoneyOfxConnector::accountInfoRequest(void) const
 
   return result;
 }
+#endif
+
 #if 0
 
 MyMoneyOfxConnector::Tag MyMoneyOfxConnector::message(const QString& _msgType, const QString& _trnType, const Tag& _request)
@@ -318,7 +354,7 @@ MyMoneyOfxConnector::Tag MyMoneyOfxConnector::message(const QString& _msgType, c
       .subtag(_request));
 }
 
-MyMoneyOfxConnector::Tag MyMoneyOfxConnector::investmentRequest(const QDate& _dtstart) const
+MyMoneyOfxConnector::Tag MyMoneyOfxConnector::investmentRequest(void) const
 {
   QString dtnow_string = QDateTime::currentDateTime().toString(Qt::ISODate).remove(QRegExp("[^0-9]"));
   QString dtstart_string = _dtstart.toString(Qt::ISODate).remove(QRegExp("[^0-9]"));
@@ -687,4 +723,3 @@ MyMoneyOfxConnector::Tag MyMoneyOfxConnector::investmentTransaction(const MyMone
   return Tag("ERROR").element("DETAILS","This transaction contains an unsupported action type");
 }
 #endif
-#endif // USE_OFX_DIRECTCONNECT
