@@ -114,13 +114,21 @@ KAccountsView::KAccountsView(QWidget *parent, const char *name) :
   connect(m_accountIcons, SIGNAL(executed(QIconViewItem*)), this, SLOT(slotOpenObject(QIconViewItem*)));
 
   connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), this, SLOT(slotLoadAccounts()));
-
+  connect(m_collapseButton, SIGNAL(clicked()), this, SLOT(slotExpandCollapse()));
+  connect(m_expandButton, SIGNAL(clicked()), this, SLOT(slotExpandCollapse()));
 }
 
 KAccountsView::~KAccountsView()
 {
 }
 
+void KAccountsView::slotExpandCollapse(void)
+{
+  if(sender()) {
+    KMyMoneyGlobalSettings::setShowAccountsExpanded(sender() == m_expandButton);
+  }
+}
+
 void KAccountsView::slotLoadAccounts(void)
 {
   m_needReload[ListView] = true;
@@ -214,13 +222,12 @@ void KAccountsView::loadIconView(void)
   ::timetrace("start load accounts icon view");
 
   // remember the positions of the icons
-  QMap<QCString, QPoint> posMap;
+  QMap<QString, QPoint> posMap;
   KMyMoneyAccountIconItem* p = dynamic_cast<KMyMoneyAccountIconItem*>(m_accountIcons->firstItem());
   for(;p; p = dynamic_cast<KMyMoneyAccountIconItem*>(p->nextItem()))
     posMap[p->itemObject().id()] = p->pos();
 
   // turn off updates to avoid flickering during reload
-  m_accountIcons->setUpdatesEnabled(false);
   m_accountIcons->setAutoArrange(true);
 
   // clear the current contents and recreate it
@@ -239,11 +246,12 @@ void KAccountsView::loadIconView(void)
 
   bool showClosedAccounts = kmymoney2->toggleAction("view_show_all_accounts")->isChecked()
       || !KMyMoneyGlobalSettings::hideClosedAccounts();
+  bool existNewIcons = false;
 
   // parse list and add all asset and liability accounts
   QMap<QString, MyMoneyAccount>::const_iterator it;
-  QPoint loc;
   for(it = accountMap.begin(); it != accountMap.end(); ++it) {
+    QPoint loc;
     if((*it).isClosed() && !showClosedAccounts)
       continue;
     const QString& pos = (*it).value("kmm-iconpos");
@@ -268,7 +276,9 @@ void KAccountsView::loadIconView(void)
         }
 
         loc = posMap[(*it).id()];
-        if(loc != QPoint()) {
+        if(loc == QPoint()) {
+          existNewIcons = true;
+        } else {
           m_accountIcons->setAutoArrange(false);
         }
 
@@ -290,22 +300,23 @@ void KAccountsView::loadIconView(void)
   m_securityMap.clear();
   m_transactionCountMap.clear();
 
+  if(existNewIcons) {
+    m_accountIcons->arrangeItemsInGrid(true);
+  }
+
   m_accountIcons->setAutoArrange(false);
-  // turn updates back on
-  m_accountIcons->setUpdatesEnabled(true);
-  m_accountIcons->repaintContents();
 
   ::timetrace("done load accounts icon view");
 }
 
 void KAccountsView::loadListView(void)
 {
-  QMap<QCString, bool> isOpen;
+  QMap<QString, bool> isOpen;
 
   ::timetrace("start load accounts list view");
   // remember the id of the current selected item
   KMyMoneyAccountTreeBaseItem *item = m_accountTree->selectedItem();
-  QCString selectedItemId = (item) ? item->id() : QCString();
+  QString selectedItemId = (item) ? item->id() : QString();
 
   // keep a map of all 'expanded' accounts
   QListViewItemIterator it_lvi(m_accountTree);
@@ -398,13 +409,17 @@ void KAccountsView::loadListView(void)
   m_accountTree->setUpdatesEnabled(true);
   m_accountTree->repaintContents();
 
+  // and in case we need to show things expanded, we'll do so
+  if(KMyMoneyGlobalSettings::showAccountsExpanded())
+    m_accountTree->slotExpandAll();
+
   // clear the current contents
   m_securityMap.clear();
   m_transactionCountMap.clear();
   ::timetrace("done load accounts list view");
 }
 
-bool KAccountsView::loadSubAccounts(KMyMoneyAccountTreeItem* parent, const QCStringList& accountList)
+bool KAccountsView::loadSubAccounts(KMyMoneyAccountTreeItem* parent, const QStringList& accountList)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -412,7 +427,7 @@ bool KAccountsView::loadSubAccounts(KMyMoneyAccountTreeItem* parent, const QCStr
   bool showClosedAccounts = kmymoney2->toggleAction("view_show_all_accounts")->isChecked()
                          || !KMyMoneyGlobalSettings::hideClosedAccounts();
 
-  QCStringList::const_iterator it_a;
+  QStringList::const_iterator it_a;
   for(it_a = accountList.begin(); it_a != accountList.end(); ++it_a) {
     const MyMoneyAccount& acc = file->account(*it_a);
     QValueList<MyMoneyPrice> prices;
@@ -588,22 +603,22 @@ void KAccountsView::slotUpdateIconPos(unsigned int action)
   if(action != KMyMoneyView::preSave)
     return;
 
+  MyMoneyFileTransaction ft;
   KMyMoneyAccountIconItem* p = dynamic_cast<KMyMoneyAccountIconItem*>(m_accountIcons->firstItem());
   for(;p; p = dynamic_cast<KMyMoneyAccountIconItem*>(p->nextItem())) {
     const MyMoneyAccount& acc = dynamic_cast<const MyMoneyAccount&>(p->itemObject());
     if(acc.value("kmm-iconpos") != point(p->pos())) {
       MyMoneyAccount a(acc);
       a.setValue("kmm-iconpos", point(p->pos()));
-      MyMoneyFileTransaction ft;
       try {
         MyMoneyFile::instance()->modifyAccount(a);
-        ft.commit();
       } catch(MyMoneyException* e) {
         kdDebug(2) << "Unable to update icon pos: " << e->what();
         delete e;
       }
     }
   }
+  ft.commit();
 }
 
 
