@@ -39,6 +39,8 @@
 #include <qpainter.h>
 #include <qheader.h>
 #include <qbuttongroup.h>
+#include <qsplitter.h>
+#include <qmap.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -68,15 +70,6 @@
 /*                               KTransactionPtrVector                            */
 /* -------------------------------------------------------------------------------*/
 
-int KTransactionPtrVector::compareItems(const QCString& s1, const QCString& s2) const
-{
-  if(s1 == s2)
-    return 0;
-  if(s1 < s2)
-    return -1;
-  return 1;
-}
-
 int KTransactionPtrVector::compareItems(const QString& s1, const QString& s2) const
 {
   if(s1 == s2)
@@ -252,13 +245,13 @@ void KTransactionPtrVector::setSortType(const TransactionSortE type)
   sort();
 }
 
-void KTransactionPtrVector::setAccountId(const QCString& id)
+void KTransactionPtrVector::setAccountId(const QString& id)
 {
   m_id = id;
   m_idMode = AccountMode;
 }
 
-void KTransactionPtrVector::setPayeeId(const QCString& id)
+void KTransactionPtrVector::setPayeeId(const QString& id)
 {
   m_id = id;
   m_idMode = PayeeMode;
@@ -294,7 +287,7 @@ void KPayeeListItem::paintCell(QPainter *p, const QColorGroup & cg, int column,
   QListViewItem::paintCell(p, cg2, column, width, align);
 }
 
-KTransactionListItem::KTransactionListItem(KListView* view, KTransactionListItem* parent, const QCString& accountId, const QCString& transactionId) :
+KTransactionListItem::KTransactionListItem(KListView* view, KTransactionListItem* parent, const QString& accountId, const QString& transactionId) :
   KListViewItem(view, parent)
 {
   m_accountId = accountId;
@@ -332,7 +325,27 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
   // create the searchline widget
   // and insert it into the existing layout
   m_searchWidget = new KListViewSearchLineWidget(m_payeesList, this);
-  KPayeesViewDeclLayout->insertWidget(2, m_searchWidget);
+  m_searchWidget->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
+  KPayeesViewDeclLayout->insertWidget(0, m_searchWidget);
+
+  m_splitter = new QSplitter(this);
+  m_payeesList->reparent(m_splitter, QPoint(0,0), true);
+  m_tabWidget->reparent(m_splitter, QPoint(0, 0), true);
+  m_splitter->setResizeMode(m_tabWidget, QSplitter::Stretch);
+  m_splitter->setOpaqueResize();
+  layout10->addWidget(m_splitter);
+
+  // use the size settings of the last run (if any)
+  KConfig *config = KGlobal::config();
+  config->setGroup("Last Use Settings");
+  QValueList<int> sizes = config->readIntListEntry("KPayeesViewSplitterSize");
+  if(sizes.size() == 2) {
+    if(!sizes[0] || !sizes[1]) {
+      sizes[0] = 1;
+      sizes[1] = 2;
+    }
+    m_splitter->setSizes(sizes);
+  }
 
   m_transactionView->setSorting(-1);
   m_transactionView->setColumnWidthMode(2, QListView::Manual);
@@ -347,6 +360,10 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
 
   checkMatchIgnoreCase->setEnabled(false);
 
+  checkEnableDefaultAccount->setChecked(false);
+  labelDefaultAccount->setEnabled(false);
+  comboDefaultAccount->setEnabled(false);
+
   KIconLoader* il = KGlobal::iconLoader();
   KGuiItem updateButtenItem( i18n("Update"),
                     QIconSet(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall)),
@@ -369,8 +386,12 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
   connect(radioKeyMatch, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
   connect(checkMatchIgnoreCase, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
 
-  connect(m_updateButton, SIGNAL(pressed()), this, SLOT(slotUpdatePayee()));
-  connect(m_helpButton, SIGNAL(pressed()), this, SLOT(slotHelp()));
+  connect(checkEnableDefaultAccount, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
+  connect(comboDefaultAccount, SIGNAL(accountSelected(const QString&)), this, SLOT(slotPayeeDataChanged()));
+  connect(buttonSelectMyAccount, SIGNAL(clicked()), this, SLOT(slotChooseDefaultAccount()));
+
+  connect(m_updateButton, SIGNAL(clicked()), this, SLOT(slotUpdatePayee()));
+  connect(m_helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
 
   connect(m_payeesList, SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)), this, SLOT(slotOpenContextMenu(KListView*, QListViewItem*, const QPoint&)));
 
@@ -387,6 +408,10 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
 
 KPayeesView::~KPayeesView()
 {
+  // remember the splitter settings for startup
+  KConfig *config = KGlobal::config();
+  config->setGroup("Last Use Settings");
+  config->writeEntry("KPayeesViewSplitterSize", m_splitter->sizes());
 }
 
 void KPayeesView::slotQueueUpdate(void)
@@ -404,6 +429,45 @@ void KPayeesView::slotActivateUpdate(void)
     slotSelectPayee();
 }
 
+void KPayeesView::slotChooseDefaultAccount(void)
+{
+    MyMoneyFile* file = MyMoneyFile::instance();
+    QMap<QString,int> account_count;
+
+  for (int i = 0; i < m_transactionPtrVector.size(); ++i) {
+    KMyMoneyTransaction* t = m_transactionPtrVector[i];
+    MyMoneySplit s = t->splitById(t->splitId());
+    const MyMoneyAccount& acc = file->account(s.accountId());
+
+    QString txt;
+    if (s.action() != MyMoneySplit::ActionAmortization
+        && acc.accountType() != MyMoneyAccount::AssetLoan
+        && !file->isTransfer(*t)
+        && t->splitCount() == 2) {
+      MyMoneySplit s0 = t->splitByAccount(s.accountId(), false);
+      if (account_count.contains(s0.accountId())) {
+        account_count[s0.accountId()]++;
+      }
+      else {
+        account_count[s0.accountId()] = 1;
+      }
+    }
+  }
+
+  QMapIterator<QString,int> most_frequent, iter;
+  most_frequent = account_count.end();
+  for (iter = account_count.begin(); iter != account_count.end(); iter++) {
+    if (iter.data() > most_frequent.data()) {
+      most_frequent = iter;
+    }
+  }
+
+  if (most_frequent != account_count.end()) {
+    checkEnableDefaultAccount->setChecked(true);
+    comboDefaultAccount->setSelected(most_frequent.key());
+  }
+}
+
 void KPayeesView::slotStartRename(void)
 {
   QListViewItemIterator it_l(m_payeesList, QListViewItemIterator::Selected);
@@ -466,7 +530,7 @@ void KPayeesView::slotRenamePayee(QListViewItem* p , int /* col */, const QStrin
   }
 }
 
-void KPayeesView::ensurePayeeVisible(const QCString& id)
+void KPayeesView::ensurePayeeVisible(const QString& id)
 {
   for (QListViewItem * item = m_payeesList->firstChild(); item; item = item->itemBelow()) {
     KPayeeListItem* p = dynamic_cast<KPayeeListItem*>(item);
@@ -564,6 +628,10 @@ void KPayeesView::slotSelectPayee(void)
     matchKeyEditList->clear();
     matchKeyEditList->insertStringList(keys);
     checkMatchIgnoreCase->setChecked(ignorecase);
+
+    checkEnableDefaultAccount->setChecked(m_payee.defaultAccountEnabled());
+    comboDefaultAccount->setSelected(m_payee.defaultAccountId());
+
     slotPayeeDataChanged();
 
     showTransactions();
@@ -614,7 +682,7 @@ void KPayeesView::showTransactions(void)
   m_transactionPtrVector.setSortType(KTransactionPtrVector::SortPostDate);
 
   QValueList<MyMoneyTransaction>::ConstIterator it_t;
-  QCString lastId;
+  QString lastId;
   int ofs = 0;
 
   for(i = 0, it_t = list.begin(); it_t != list.end(); ++it_t) {
@@ -753,6 +821,25 @@ void KPayeesView::slotPayeeDataChanged(void)
         rc |= (keys != matchKeyEditList->items());
       }
     }
+
+    rc |= (checkEnableDefaultAccount->isChecked() != m_payee.defaultAccountEnabled());
+    if (checkEnableDefaultAccount->isChecked()) {
+      comboDefaultAccount->setEnabled(true);
+      labelDefaultAccount->setEnabled(true);
+      // this is only going to understand the first in the list of selected accounts
+      if (comboDefaultAccount->selectedAccounts().empty()) {
+        rc |= !m_payee.defaultAccountId().isEmpty();
+      }
+      else {
+        QString temp = comboDefaultAccount->selectedAccounts().front();
+        rc |= ( temp.isEmpty() != m_payee.defaultAccountId().isEmpty())
+              || (!m_payee.defaultAccountId().isEmpty() && temp != m_payee.defaultAccountId());
+      }
+    }
+    else {
+      comboDefaultAccount->setEnabled(false);
+      labelDefaultAccount->setEnabled(false);
+    }
   }
   m_updateButton->setEnabled(rc);
 }
@@ -761,6 +848,7 @@ void KPayeesView::slotUpdatePayee(void)
 {
   if(m_updateButton->isEnabled()) {
     MyMoneyFileTransaction ft;
+    m_updateButton->setEnabled(false);
     try {
       m_payee.setName(m_newName);
       m_payee.setAddress(addressEdit->text());
@@ -769,6 +857,15 @@ void KPayeesView::slotUpdatePayee(void)
       m_payee.setEmail(emailEdit->text());
       m_payee.setNotes(notesEdit->text());
       m_payee.setMatchData(static_cast<MyMoneyPayee::payeeMatchType>(m_matchType->selectedId()), checkMatchIgnoreCase->isChecked(), matchKeyEditList->items());
+      m_payee.setDefaultAccountId();
+
+      if (checkEnableDefaultAccount->isChecked()) {
+        QString temp;
+        if (!comboDefaultAccount->selectedAccounts().empty()) {
+          temp = comboDefaultAccount->selectedAccounts().front();
+          m_payee.setDefaultAccountId(temp);
+        }
+      }
 
       MyMoneyFile::instance()->modifyPayee(m_payee);
       ft.commit();
@@ -778,7 +875,6 @@ void KPayeesView::slotUpdatePayee(void)
         (e->what() + " " + i18n("thrown in") + " " + e->file()+ ":%1").arg(e->line()));
       delete e;
     }
-    m_updateButton->setEnabled(false);
   }
 }
 
@@ -795,6 +891,10 @@ void KPayeesView::readConfig(void)
 
   m_payeesList->setDefaultRenameAction(
            KMyMoneyGlobalSettings::focusChangeIsEnter() ? QListView::Accept : QListView::Reject);
+
+  //initialize the account list?
+  comboDefaultAccount->loadList((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability | MyMoneyAccount::Income | MyMoneyAccount::Expense));
+
 }
 
 void KPayeesView::show(void)
@@ -841,8 +941,8 @@ void KPayeesView::loadPayees(void)
   if(m_inSelection)
     return;
 
-  QMap<QCString, bool> isSelected;
-  QCString id;
+  QMap<QString, bool> isSelected;
+  QString id;
 
   ::timetrace("Start KPayeesView::loadPayees");
   readConfig();
@@ -930,7 +1030,7 @@ void KPayeesView::slotTransactionDoubleClicked(QListViewItem* i)
     emit transactionSelected(item->accountId(), item->transactionId());
 }
 
-void KPayeesView::slotSelectPayeeAndTransaction(const QCString& payeeId, const QCString& accountId, const QCString& transactionId)
+void KPayeesView::slotSelectPayeeAndTransaction(const QString& payeeId, const QString& accountId, const QString& transactionId)
 {
   if(!isVisible())
     return;
