@@ -155,7 +155,8 @@ void KReportsView::KReportTab::saveAs( const QString& filename, bool includeCSS
     }
     else {
       QTextStream stream(&file);
-      QRegExp exp("(.*)(<link.*css\" href=)\"(.*)\">(<meta.*utf-8\" />)(.*)");
+      
+      QRegExp exp(QString("(.*)(<link.*css\" href=)\"(.*)\">(<meta.*%1\" />)(.*)").arg(KGlobal::locale()->encoding()));
       QString table = createTable();
       if(exp.search(table) != -1 && includeCSS) {
         QFile cssFile(exp.cap(3));
@@ -239,7 +240,7 @@ QString KReportsView::KReportTab::createTable(const QString& links)
   QString header = QString("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\">\n") +
     QString("<html><head><link rel=\"stylesheet\" type=\"text/css\" href=\"%1\">").arg(filename);
 
-  header += "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />";
+  header += QString("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=%1\" />").arg(KGlobal::locale()->encoding());
   header += KMyMoneyUtils::variableCSS();
 
   header += "</head><body>\n";
